asianMC_strikes = function(params,strikes,q=0,T=1,dt=250,no=1000000,ifPlot=FALSE,n_plotpaths=10){
  # See "main" for descirptions of variables
  tictoc::tic(0)
  
  r = params$GLOBAL$riskfreeRate
  s0 = params$GLOBAL$s0
  days = round(T/dt)
  T = days*dt
  
  simprice = data.frame(matrix(0, ncol = 3, nrow = length(strikes)))
  colnames(simprice) = c("NIG_price","VG_price","GBM_price")
  rownames(simprice) = strikes
                        
  for(i in 1:3){ # 1 = NIG, 2 = VG, 3 = GBM
    tictoc::tic(i)
    
    if(i == 1){ # NIG
      alpha = params$NIG$alpha
      beta = params$NIG$beta
      delta = params$NIG$delta
      omega = delta*( sqrt(alpha^2-(beta+1)^2) - sqrt(alpha^2-beta^2) )
      mu = r - q + omega # Mean corrected mu
      
      dx = matrix( rghyp(n=days*no,object=NIG.ad(alpha = alpha, delta = (delta)*(dt), beta = beta, mu = mu*dt)), nrow = no,ncol = days )
      s = matrix(s0, nrow = no, ncol = days)
      
      price = matrix(NA, nrow = length(strikes), ncol = no)
      
      for (i in 1:no) {
        for (t in 2:days) {
          s[i, t] = s[i, t - 1] * exp(dx[i,t])
          if(t==days & i%%10000 == 0){print(i)}
        }
        for (i_strike in 1:length(strikes)){
          price[i_strike,i] = exp(-r * T) * max(c((mean(s[i, ]) - strikes[i_strike]), 0))
        }
      }
      
      for (i_strike in 1:length(strikes)){
      simprice$NIG_price[i_strike] = mean(price[i_strike,])
      }
      nigtime = tictoc::toc(i, quiet = TRUE)
      nigtime = as.numeric(nigtime$toc - nigtime$tic)
      
      if (ifPlot) {
        title = "NIG"
        MC_plot(s,no,days,n_plotpaths,title)
      }
      
    }else if(i == 2){ # VG
      lambda = params$VG$lambda
      mu = params$VG$mu
      sigma = params$VG$sigma
      gamma = params$VG$gamma
      omega = lambda*log( 1 - sigma^2/(2*lambda) - gamma/lambda )
      mu = r - q + omega # Mean corrected mu
      
      VGobject_t = VG(lambda = lambda*dt, mu = dt*mu, sigma = sigma*sqrt(dt), gamma = dt*gamma)
      dx = matrix( rghyp(n=days*no,object=VGobject_t), nrow = no,ncol = days )
      
      s = matrix(s0, nrow = no, ncol = days)
      
      price = matrix(NA, nrow = length(strikes), ncol = no)
      
      for (i in 1:no) {
        for (t in 2:days) {
          s[i, t] = s[i, t - 1] * exp(dx[i,t])
          if(t==days & i%%10000 == 0){print(i)}
        }
        for (i_strike in 1:length(strikes)){
          price[i_strike,i] = exp(-r * T) * max(c((mean(s[i, ]) - strikes[i_strike]), 0))
        }
      }
      
      for (i_strike in 1:length(strikes)){
        simprice$VG_price[i_strike] = mean(price[i_strike,])
      }
      vgtime = tictoc::toc(i, quiet = TRUE)
      vgtime = as.numeric(vgtime$toc - vgtime$tic)
      
      if (ifPlot) {
        title = "VG"
        MC_plot(s,no,days,n_plotpaths,title)
      }
      
    }else{#i = 3 # GBM
      mu = params$GBM$mean
      sd = params$GBM$sd
      mu = r - q - 1/2*sigma^2 # Mean corrected mu
      
      dx = matrix( rnorm(n=days*no,mean=mu*dt,sd=sqrt(dt)*sd), nrow = no,ncol = days )
      s = matrix(s0, nrow = no, ncol = days)
      
      price = matrix(NA, nrow = length(strikes), ncol = no)
      
      for (i in 1:no) {
        for (t in 2:days) {
          s[i, t] = s[i, t - 1] * exp(dx[i,t])
          if(t==days & i%%10000 == 0){print(i)}
        }
        for (i_strike in 1:length(strikes)){
          price[i_strike,i] = exp(-r * T) * max(c((mean(s[i, ]) - strikes[i_strike]), 0))
        }
      }
      
      for (i_strike in 1:length(strikes)){
        simprice$GBM_price[i_strike] = mean(price[i_strike,])
      }
      gbmtime = tictoc::toc(i, quiet = TRUE)
      gbmtime = as.numeric(gbmtime$toc - gbmtime$tic)
      
      if (ifPlot) {
        title = "GBM"
        MC_plot(s,no,days,n_plotpaths,title)
      }
      
    } #else
    
  } # for(i in 1:3)
  
  totaltime = tictoc::toc(0, quiet = TRUE)
  times = data.frame(t(c(nigtime=nigtime,vgtime=vgtime,gbmtime=gbmtime,totaltime=totaltime)))
  
  return(list(prices=simprice, times=times))
}
