fitParams = function(data,ifPlot=FALSE,ifTest=FALSE,ifPlotKS=FALSE){
# data: Data Frame containing: Time | logreturns
# ifPlot: Logical. True => Plot fitted models and display evaluating statistics
# ifTest: Logical. True => Perform a Goodness-of-fit test (Kologorov Smirnov)
  
  
  # Built in functionality to ID best fitted model based on AIC alone
  bestmodel = stepAIC.ghyp(data[,2])$best.model
  bestmodel_name = getElement(bestmodel, "model")[3]
  
  
  # Fitting ####
  fittedVG = ghyp::fit.VGuv(data[,2])
  fittedNIG = ghyp::fit.NIGuv(data[,2])
  fittednormal = MASS::fitdistr(data[,2], "normal")
  
  
  # Goodness-of-fit test (Kolmogorov-Smirnov test) ####
  ks = NULL # avoids error when ifTest = FALSE
  if(ifTest){
  
    filename = file.path("C:","Users/marku/Dropbox/Master/Code/fig/fit",paste(deparse(substitute(data)), "_ks.pdf", sep = ""))
    ks = kolmogorovSmirnovTest_v2(data,fittedNIG,fittedVG,fittednormal,ifPlotKS,filename)
    dev.set(2)
    
  }
  
  # Extract Parameters ####
  nigparams = data.frame(cbind(as.data.frame(coef(fittedNIG, type = "alpha.delta")),data.frame(AIC(fittedNIG),logLik(fittedNIG))))
  vgparams = data.frame(cbind(as.data.frame(coef(fittedVG, type = "chi.psi")),data.frame(AIC(fittedVG),logLik(fittedVG))))
  normalparams = data.frame(cbind(as.data.frame(t(fittednormal$estimate)),data.frame(AIC(fittednormal),fittednormal$loglik)))
  
  # Store results
  parameters = list(NIG=nigparams,VG=vgparams,GBM=normalparams,KS=ks,BESTMODEL=bestmodel_name,GLOBAL=NULL)
  
  # Plotting ####
  if(ifPlot){
    
    print(noquote(paste(c('Best model (based on AIC alone) for',paste(deparse(substitute(data)),'is', bestmodel_name)))))
    
    # Densities:
    # filename = file.path("C:","Users/marku/Dropbox/Master/Code/fig/fit",paste(deparse(substitute(data)), "_density.pdf", sep = ""))
    # pdf(file = filename, width=6, height=4)
    
    main = paste("Fitted densities for ",toupper(deparse(substitute(data))), sep = "")
    xlim = c(min(data[,2]),max(data[,2]))
    x = seq(xlim[1],xlim[2],(diff(xlim))/99)
    hist(data[,2], breaks = x, freq = FALSE, border = "gray", main = main, xlab = "Log returns", ylab = "Density")
    lines(fittedVG, col = "blue")
    lines(fittedNIG, col = "red")
    lines(x,dnorm(x, mean = normalparams$mean, sd = normalparams$sd), type = 'l', col = "black")
    legend(x = "topleft", c("Normal","VG","NIG",toupper(deparse(substitute(data)))), fill = c("black","blue","red","gray"),bty = "n")
    # dev.off()
    
    # QQ-Plot
    # filename = file.path("C:","Users/marku/Dropbox/Master/Code/fig/fit",paste(deparse(substitute(data)), "_qq.pdf", sep = ""))
    # pdf(file = filename, width=6, height=4)
    
    # main = paste("QQ-Plot for ",toupper(deparse(substitute(data))))
    # ghyp::qqghyp(fittedNIG, data = data[,2], ghyp.pch = 1, gauss.pch = 1, ghyp.col = "red", gauss.lty = 1, ghyp.lty = 0, gaussian = TRUE, main = main, gauss.col = "black", plot.legend = FALSE)
    # ghyp::qqghyp(fittedVG, data = data[,2], ghyp.col = "blue", gauss.pch = 1, gauss.lty = 0, main = main, add = TRUE, plot.legend = FALSE)
    # legend(x = "topleft", c("Normal","VG","NIG"), fill = c("black","blue","red"),bty = "n")
    # dev.off()
    # dev.set(2)
  }
  
  return(parameters)
  
}