# Libraries
library(tidyverse)
library(pracma)
library(ghyp)
library(MASS)
library(xlsx)

# clear objects from workspace
rm(list = setdiff(ls(), c("ifPlot","ifTest","ifPlotKS","ifPlotMC","markets")))

# Functions
source("fitParams.R")
source("kolmogorovSmirnovTest_v2.R")
source("asianMC.R")
source("asianMC_strikes.R")
source("MC_plot.R")
source("GBMasianPI.R")
source("NIGasianPI.R")
source("VGasianPI.R")

# Load Data ####
source("loadData.R")

# Get Parameters
if(markets$ifdax){daxParams = fitParams(data = dax,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
if(markets$ifndx){ndxParams = fitParams(data = ndx,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
if(markets$ifomxc){omxcParams = fitParams(data = omxc,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
if(markets$ifomxs){omxsParams = fitParams(data = omxs,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
if(markets$ifosebx){osebxParams = fitParams(data = osebx,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
if(markets$ifspx){spxParams = fitParams(data = spx,ifPlot = ifPlot, ifTest = ifTest, ifPlotKS = ifPlotKS)}
# dev.set(2) # Ensure return to standard graphical device after plotting

if(ifTest){
  ks_quantiles = data.frame(matrix(data = c("alpha","K_alpha",0.8, 1.0727, 0.9, 1.2238, 0.95, 1.3581, 0.975, 1.4802, 0.99, 1.6276, 0.999, 1.9495), ncol = 7, nrow = 2))
  ks = data.frame(matrix(data = c("DAX",daxParams[[4]],"Nasdaq",ndxParams[[4]],"OMXC",omxcParams[[4]],"OMXS",omxsParams[[4]],"OSEBX",osebxParams[[4]],"SPX",spxParams[[4]]), ncol = 4, byrow = TRUE))
  colnames(ks) = c("Market","NIG","VG","Normal")
}

# Parameters
n_plotpaths = 10
gridsizes = 2^c(8,10,12,14)
q = 0 # Continuous coupon yield
T = 250 # 1 # Maturity: Days # Years
dt = 1 #  1/250 # Time step: Days # Years (approx num. business days a year) (Daily measuring)
diffs0Strike = 0
if(markets$ifdax){daxParams$GLOBAL = data.frame(t(c(riskfreeRate = rdax, s0 = s0dax, strike = s0dax + diffs0Strike)))}
if(markets$ifndx){ndxParams$GLOBAL = data.frame(t(c(riskfreeRate = rndx, s0 = s0ndx, strike = s0ndx + diffs0Strike)))}
if(markets$ifomxc){omxcParams$GLOBAL = data.frame(t(c(riskfreeRate = romxc, s0 = s0omxc, strike = s0omxc + diffs0Strike)))}
if(markets$ifomxs){omxsParams$GLOBAL = data.frame(t(c(riskfreeRate = romxs, s0 = s0omxs, strike = s0omxs + diffs0Strike)))}
if(markets$ifspx){spxParams$GLOBAL = data.frame(t(c(riskfreeRate = rspx, s0 = s0spx, strike = s0spx + diffs0Strike)))}
if(markets$ifosebx){osebxParams$GLOBAL = data.frame(t(c(riskfreeRate = rosebx, s0 = s0osebx, strike = s0osebx + diffs0Strike)))}

# clear command window
cat("\014")
